@@ -515,6 +515,7 @@ g_string_append_len (GString	 *string,
   return g_string_insert_len (string, -1, val, len);
 }
 
+#undef g_string_append_c
 GString*
 g_string_append_c (GString *string,
 		   gchar    c)
@@ -702,10 +703,11 @@ GString*
 g_string_ascii_down (GString *string)
 {
   gchar *s;
-  gint n = string->len;
+  gint n;
 
   g_return_val_if_fail (string != NULL, NULL);
 
+  n = string->len;
   s = string->str;
 
   while (n)
@@ -732,10 +734,11 @@ GString*
 g_string_ascii_up (GString *string)
 {
   gchar *s;
-  gint n = string->len;
+  gint n;
 
   g_return_val_if_fail (string != NULL, NULL);
 
+  n = string->len;
   s = string->str;
 
   while (n)
@@ -764,10 +767,11 @@ GString*
 g_string_down (GString *string)
 {
   guchar *s;
-  glong n = string->len;    
+  glong n;
 
   g_return_val_if_fail (string != NULL, NULL);
 
+  n = string->len;    
   s = (guchar *) string->str;
 
   while (n)
@@ -797,10 +801,11 @@ GString*
 g_string_up (GString *string)
 {
   guchar *s;
-  glong n = string->len;
+  glong n;
 
   g_return_val_if_fail (string != NULL, NULL);
 
+  n = string->len;
   s = (guchar *) string->str;
 
   while (n)
